pub struct TextObject<State = Readonly> { /* private fields */ }Implementations
Sourceimpl TextObject<Readonly>
impl TextObject<Readonly>
pub fn from(content: &str) -> TextObject<Readonly>
pub fn with_write(self) -> TextObject<Write>
Sourceimpl TextObject<Write>
impl TextObject<Write>
pub fn insert_char(&mut self, c: char, cursor: &Cursor)
pub fn insert_newline(&mut self, cursor: &Cursor)
pub fn erase_backwards_up_to_line_start(&mut self, cursor: &Cursor)
pub fn erase_previous_char(&mut self, cursor: &Cursor)
pub fn erase_current_char(&mut self, cursor: &Cursor)
pub fn current_line(&self, cursor: &Cursor) -> Option<&str>
pub fn line_len_with_linebreak(&self, line: usize) -> usize
pub fn line_len(&self, line: usize) -> usize
pub fn erase_until_eol(&mut self, cursor: &Cursor)
pub fn find_char_after_whitespace(&self, cursor: &Cursor) -> (usize, usize)
pub fn find_char_before_whitespace(&self, cursor: &Cursor) -> (usize, usize)
pub fn find_char_after_separator(&self, cursor: &Cursor) -> (usize, usize)
pub fn find_char_before_separator(&self, cursor: &Cursor) -> (usize, usize)
pub fn find_empty_line_above(&self, cursor: &Cursor) -> usize
pub fn find_empty_line_below(&self, cursor: &Cursor) -> usize
pub fn len_lines(&self) -> usize
pub fn delete_line(&mut self, line: usize)
Sourcepub fn delete_word(&mut self, cursor: &Cursor)
pub fn delete_word(&mut self, cursor: &Cursor)
deletes a word forward in one of two ways:
- if the current character is alphanumeric, then this delete up to the first non alphanumeric character
- if the current character is non alphanumeric, then delete up to the first alphanumeric character
Sourcepub fn delete_word_backwards(&mut self, cursor: &Cursor) -> usize
pub fn delete_word_backwards(&mut self, cursor: &Cursor) -> usize
deletes a word backwards in one of two ways:
- if the current character is alphanumeric, then this delete up to the first non alphanumeric character
- if the current character is non alphanumeric, then delete up to the first alphanumeric character
will always return how many columns to advance the cursor
pub fn insert_line_below(&mut self, cursor: &Cursor, tree: Option<&Tree>)
pub fn insert_line_above(&mut self, cursor: &Cursor, tree: Option<&Tree>)
pub fn find_oposing_token(&mut self, cursor: &Cursor) -> (usize, usize)